@@ -3,39 +3,21 @@
 #define _BSD_SOURCE
 #define _XOPEN_SOURCE 700
 
-#include <sys/wait.h>
 #include <stdlib.h>
-#include <stdio.h>
 #include <string.h>
 #include <limits.h>
-#include <errno.h>
 #include <glib.h>
-#include <glib/gi18n.h>
-#ifdef WITH_MAGIC
-#include <magic.h>
-#endif
-#include <unistd.h>
 
 #include <girara/datastructures.h>
 #include <girara/utils.h>
-#include <girara/statusbar.h>
-#include <girara/session.h>
-#include <girara/settings.h>
 
 #include "adjustment.h"
 #include "document.h"
 #include "utils.h"
 #include "zathura.h"
-#include "render.h"
-#include "database.h"
 #include "page.h"
-#include "page-widget.h"
 #include "plugin.h"
-
-/** Read a most GT_MAX_READ bytes before falling back to file. */
-static const size_t GT_MAX_READ = 1 << 16;
-
-static const gchar* guess_type(const char* path);
+#include "content-type.h"
 
 /**
  * Document
@@ -86,7 +68,7 @@ zathura_document_open(zathura_plugin_manager_t* plugin_manager, const char*
     return NULL;
   }
 
-  const gchar* content_type = guess_type(path);
+  const char* content_type = guess_content_type(path);
   if (content_type == NULL) {
     girara_error("Could not determine file type.");
     return NULL;
@@ -122,11 +104,19 @@ zathura_document_open(zathura_plugin_manager_t* plugin_manager, const char*
 
   if (plugin == NULL) {
     girara_error("unknown file type\n");
-    *error = ZATHURA_ERROR_UNKNOWN;
+    if (error != NULL) {
+      *error = ZATHURA_ERROR_UNKNOWN;
+    }
     goto error_free;
   }
 
-  document = g_malloc0(sizeof(zathura_document_t));
+  document = g_try_malloc0(sizeof(zathura_document_t));
+  if (document == NULL) {
+    if (error != NULL) {
+      *error = ZATHURA_ERROR_OUT_OF_MEMORY;
+    }
+    goto error_free;
+  }
 
   document->file_path   = real_path;
   document->basename    = g_path_get_basename(real_path);
@@ -665,127 +655,6 @@ zathura_document_get_information(zathura_document_t* document, zathura_error_t*
   return result;
 }
 
-static const gchar*
-guess_type(const char* path)
-{
-  const gchar* content_type = NULL;
-#ifdef WITH_MAGIC
-  const char* mime_type = NULL;
-
-  /* creat magic cookie */
-  const int flags =
-    MAGIC_MIME_TYPE |
-    MAGIC_SYMLINK |
-    MAGIC_NO_CHECK_APPTYPE |
-    MAGIC_NO_CHECK_CDF |
-    MAGIC_NO_CHECK_ELF |
-    MAGIC_NO_CHECK_ENCODING;
-  magic_t magic = magic_open(flags);
-  if (magic == NULL) {
-    girara_debug("failed creating the magic cookie");
-    goto cleanup;
-  }
-
-  /* ... and load mime database */
-  if (magic_load(magic, NULL) < 0) {
-    girara_debug("failed loading the magic database: %s", magic_error(magic));
-    goto cleanup;
-  }
-
-  /* get the mime type */
-  mime_type = magic_file(magic, path);
-  if (mime_type == NULL) {
-    girara_debug("failed guessing filetype: %s", magic_error(magic));
-    goto cleanup;
-  }
-
-  girara_debug("magic detected filetype: %s", mime_type);
-  content_type = g_strdup(mime_type);
-
-cleanup:
-  if (magic != NULL) {
-    magic_close(magic);
-  }
-
-  if (content_type != NULL) {
-    return content_type;
-  }
-  /* else fallback to g_content_type_guess method */
-#endif /*WITH_MAGIC*/
-  gboolean uncertain = FALSE;
-  content_type = g_content_type_guess(path, NULL, 0, &uncertain);
-  if (content_type == NULL) {
-    girara_debug("g_content_type failed\n");
-  } else {
-    if (uncertain == FALSE) {
-      girara_debug("g_content_type detected filetype: %s", content_type);
-      return content_type;
-    }
-    girara_debug("g_content_type is uncertain, guess: %s", content_type);
-  }
-
-  FILE* f = fopen(path, "rb");
-  if (f == NULL) {
-    return NULL;
-  }
-
-  const int fd = fileno(f);
-  guchar* content = NULL;
-  size_t length = 0u;
-  ssize_t bytes_read = -1;
-  while (uncertain == TRUE && length < GT_MAX_READ && bytes_read != 0) {
-    g_free((void*)content_type);
-    content_type = NULL;
-
-    content = g_realloc(content, length + BUFSIZ);
-    bytes_read = read(fd, content + length, BUFSIZ);
-    if (bytes_read == -1) {
-      break;
-    }
-
-    length += bytes_read;
-    content_type = g_content_type_guess(NULL, content, length, &uncertain);
-    girara_debug("new guess: %s uncertain: %d, read: %zu", content_type, uncertain, length);
-  }
-
-  fclose(f);
-  g_free(content);
-  if (uncertain == FALSE) {
-    return content_type;
-  }
-
-  g_free((void*)content_type);
-  content_type = NULL;
-
-  girara_debug("falling back to file");
-
-  GString* command = g_string_new("file -b --mime-type ");
-  char* tmp        = g_shell_quote(path);
-
-  g_string_append(command, tmp);
-  g_free(tmp);
-
-  GError* error = NULL;
-  char* out = NULL;
-  int ret = 0;
-  g_spawn_command_line_sync(command->str, &out, NULL, &ret, &error);
-  g_string_free(command, TRUE);
-  if (error != NULL) {
-    girara_warning("failed to execute command: %s", error->message);
-    g_error_free(error);
-    g_free(out);
-    return NULL;
-  }
-  if (WEXITSTATUS(ret) != 0) {
-    girara_warning("file failed with error code: %d", WEXITSTATUS(ret));
-    g_free(out);
-    return NULL;
-  }
-
-  g_strdelimit(out, "\n\r", '\0');
-  return out;
-}
-
 zathura_plugin_t*
 zathura_document_get_plugin(zathura_document_t* document)
 {
