@@ -14,9 +14,14 @@
 #include <girara/statusbar.h>
 #include <girara/settings.h>
 #include <girara/shortcuts.h>
+#include <girara/template.h>
 #include <glib/gstdio.h>
 #include <glib/gi18n.h>
 
+#ifdef G_OS_UNIX
+#include <glib-unix.h>
+#endif
+
 #include "bookmarks.h"
 #include "callbacks.h"
 #include "config.h"
@@ -35,6 +40,7 @@
 #include "plugin.h"
 #include "adjustment.h"
 #include "dbus-interface.h"
+#include "css-definitions.h"
 
 typedef struct zathura_document_info_s {
   zathura_t* zathura;
@@ -50,6 +56,10 @@ static void zathura_jumplist_reset_current(zathura_t* zathura);
 static void zathura_jumplist_append_jump(zathura_t* zathura);
 static void zathura_jumplist_save(zathura_t* zathura);
 
+#ifdef G_OS_UNIX
+static gboolean zathura_signal_sigterm(gpointer data);
+#endif
+
 /* function implementation */
 zathura_t*
 zathura_create(void)
@@ -73,6 +83,11 @@ zathura_create(void)
     goto error_out;
   }
 
+#ifdef G_OS_UNIX
+  /* signal handler */
+  zathura->signals.sigterm = g_unix_signal_add(SIGTERM, zathura_signal_sigterm, zathura);
+#endif
+
   zathura->ui.session->global.data = zathura;
 
   return zathura;
@@ -208,12 +223,12 @@ zathura_init(zathura_t* zathura)
     zathura->database = zathura_sqldatabase_new(tmp);
     g_free(tmp);
 #endif
-  } else {
+  } else if (g_strcmp0(database, "null") != 0) {
     girara_error("Database backend '%s' is not supported.", database);
   }
   g_free(database);
 
-  if (zathura->database == NULL) {
+  if (zathura->database == NULL && g_strcmp0(database, "null") != 0) {
     girara_error("Unable to initialize database. Bookmarks won't be available.");
   } else {
     g_object_set(zathura->ui.session->command_history, "io", zathura->database, NULL);
@@ -232,6 +247,37 @@ zathura_init(zathura_t* zathura)
   zathura->jumplist.size = 0;
   zathura->jumplist.cur = NULL;
 
+  /* CSS for index mode */
+  GiraraTemplate* csstemplate = girara_session_get_template(zathura->ui.session);
+
+  static const char* index_settings[] = {
+    "index-fg",
+    "index-bg",
+    "index-active-fg",
+    "index-active-bg"
+  };
+
+  for (size_t s = 0; s < LENGTH(index_settings); ++s) {
+    girara_template_add_variable(csstemplate, index_settings[s]);
+
+    char* tmp_value = NULL;
+    GdkRGBA rgba = { 0, 0, 0, 0 };
+    girara_setting_get(zathura->ui.session, index_settings[s], &tmp_value);
+    if (tmp_value != NULL) {
+      gdk_rgba_parse(&rgba, tmp_value);
+      g_free(tmp_value);
+    }
+
+    char* color = gdk_rgba_to_string(&rgba);
+    girara_template_set_variable_value(csstemplate,
+        index_settings[s], color);
+    g_free(color);
+  }
+
+  char* css = g_strdup_printf("%s\n%s", girara_template_get_base(csstemplate), CSS_TEMPLATE_INDEX);
+  girara_template_set_base(csstemplate, css);
+  g_free(css);
+
   /* Start D-Bus service */
   bool dbus = true;
   girara_setting_get(zathura->ui.session, "dbus-service", &dbus);
@@ -737,6 +783,10 @@ document_open(zathura_t* zathura, const char* path, const char* password,
         G_CALLBACK(cb_page_widget_text_selected), zathura);
     g_signal_connect(G_OBJECT(page_widget), "image-selected",
         G_CALLBACK(cb_page_widget_image_selected), zathura);
+    g_signal_connect(G_OBJECT(page_widget), "enter-link",
+        G_CALLBACK(cb_page_widget_link), (gpointer) true);
+    g_signal_connect(G_OBJECT(page_widget), "leave-link",
+        G_CALLBACK(cb_page_widget_link), (gpointer) false);
   }
 
   /* view mode */
@@ -1384,3 +1434,18 @@ zathura_jumplist_save(zathura_t* zathura)
     cur->y = zathura_document_get_position_y(zathura->document);
   }
 }
+
+#ifdef G_OS_UNIX
+static gboolean
+zathura_signal_sigterm(gpointer data)
+{
+  if (data == NULL) {
+    return TRUE;
+  }
+
+  zathura_t* zathura = (zathura_t*) data;
+  cb_destroy(NULL, zathura);
+
+  return TRUE;
+}
+#endif
